@@ -1,6 +1,7 @@
 #![warn(clippy::all, clippy::dbg_macro)]
 
 use std::{
+    collections::HashSet,
     io::{Write, stdout},
     process::ExitCode,
 };
@@ -14,7 +15,7 @@ use clap_complete::Generator;
 use clap_verbosity_flag::InfoLevel;
 use etcetera::AppStrategy as _;
 use finding::{Confidence, Persona, Severity};
-use github_api::{GitHubHost, GitHubToken};
+use github::{GitHubHost, GitHubToken};
 use indicatif::ProgressStyle;
 use owo_colors::OwoColorize;
 use registry::input::{InputKey, InputRegistry};
@@ -22,20 +23,22 @@ use registry::{AuditRegistry, FindingRegistry};
 use state::AuditState;
 use terminal_link::Link;
 use thiserror::Error;
-use tracing::{Span, info_span, instrument};
+use tracing::{Span, info_span, instrument, warn};
 use tracing_indicatif::{IndicatifLayer, span_ext::IndicatifSpanExt};
 use tracing_subscriber::{EnvFilter, layer::SubscriberExt as _, util::SubscriberInitExt as _};
 
 use crate::{
     config::{Config, ConfigError, ConfigErrorInner},
-    github_api::Client,
+    github::Client,
+    models::AsDocument,
     registry::input::CollectionError,
+    utils::once::warn_once,
 };
 
 mod audit;
 mod config;
 mod finding;
-mod github_api;
+mod github;
 #[cfg(feature = "lsp")]
 mod lsp;
 mod models;
@@ -44,6 +47,18 @@ mod registry;
 mod state;
 mod utils;
 
+#[cfg(all(
+    not(target_family = "windows"),
+    any(
+        target_arch = "x86_64",
+        target_arch = "aarch64",
+        // NOTE(ww): Not a build we currently support.
+        // target_arch = "powerpc64"
+    )
+))]
+#[global_allocator]
+static GLOBAL: tikv_jemallocator::Jemalloc = tikv_jemallocator::Jemalloc;
+
 // TODO: Dedupe this with the top-level `sponsors.json` used by the
 // README + docs site.
 const THANKS: &[(&str, &str)] = &[("Grafana Labs", "https://grafana.com")];
@@ -141,8 +156,8 @@ struct App {
     ///
     /// By default, all workflows and composite actions are collected,
     /// while honoring `.gitignore` files.
-    #[arg(long, value_enum, default_value_t)]
-    collect: CollectionMode,
+    #[arg(long, default_values = ["default"], num_args=1.., value_delimiter=',')]
+    collect: Vec<CliCollectionMode>,
 
     /// Fail instead of warning on syntax and schema errors
     /// in collected inputs.
@@ -203,6 +218,7 @@ impl App {
 // is fully removed.
 #[derive(Debug, Copy, Clone, ValueEnum)]
 enum CliSeverity {
+    #[value(hide = true)]
     Unknown,
     Informational,
     Low,
@@ -214,6 +230,7 @@ enum CliSeverity {
 // is fully removed.
 #[derive(Debug, Copy, Clone, ValueEnum)]
 enum CliConfidence {
+    #[value(hide = true)]
     Unknown,
     Low,
     Medium,
@@ -341,39 +358,128 @@ impl From<ColorMode> for anstream::ColorChoice {
 }
 
 /// How `zizmor` collects inputs from local and remote repository sources.
-#[derive(Copy, Clone, Debug, Default, ValueEnum)]
-pub(crate) enum CollectionMode {
+#[derive(Copy, Clone, Debug, Default, ValueEnum, Eq, PartialEq, Hash)]
+pub(crate) enum CliCollectionMode {
     /// Collect all possible inputs, ignoring `.gitignore` files.
     All,
     /// Collect all possible inputs, respecting `.gitignore` files.
     #[default]
     Default,
     /// Collect only workflow definitions.
+    ///
+    /// Deprecated; use `--collect=workflows`
+    #[value(hide = true)]
     WorkflowsOnly,
     /// Collect only action definitions (i.e. `action.yml`).
+    ///
+    /// Deprecated; use `--collect=actions`
+    #[value(hide = true)]
     ActionsOnly,
+    /// Collect workflows.
+    Workflows,
+    /// Collect action definitions (i.e. `action.yml`).
+    Actions,
+    /// Collect Dependabot configuration files (i.e. `dependabot.yml`).
+    Dependabot,
 }
 
-impl CollectionMode {
+#[derive(Copy, Clone, Debug, Eq, PartialEq, Hash)]
+pub(crate) enum CollectionMode {
+    All,
+    Default,
+    Workflows,
+    Actions,
+    Dependabot,
+}
+
+pub(crate) struct CollectionModeSet(HashSet<CollectionMode>);
+
+impl From<&[CliCollectionMode]> for CollectionModeSet {
+    fn from(modes: &[CliCollectionMode]) -> Self {
+        if modes.len() > 1
+            && modes.iter().any(|mode| {
+                matches!(
+                    mode,
+                    CliCollectionMode::WorkflowsOnly | CliCollectionMode::ActionsOnly
+                )
+            })
+        {
+            let mut cmd = App::command();
+
+            cmd.error(
+                clap::error::ErrorKind::ArgumentConflict,
+                "`workflows-only` and `actions-only` cannot be combined with other collection modes",
+            )
+            .exit();
+        }
+
+        Self(
+            modes
+                .iter()
+                .map(|mode| match mode {
+                    CliCollectionMode::All => CollectionMode::All,
+                    CliCollectionMode::Default => CollectionMode::Default,
+                    CliCollectionMode::WorkflowsOnly => {
+                        warn!("--collect=workflows-only is deprecated; use --collect=workflows instead");
+                        warn!("future versions of zizmor will reject this mode");
+
+                        CollectionMode::Workflows
+                    }
+                    CliCollectionMode::ActionsOnly => {
+                        warn!("--collect=actions-only is deprecated; use --collect=actions instead");
+                        warn!("future versions of zizmor will reject this mode");
+
+                        CollectionMode::Actions
+                    }
+                    CliCollectionMode::Workflows => CollectionMode::Workflows,
+                    CliCollectionMode::Actions => CollectionMode::Actions,
+                    CliCollectionMode::Dependabot => CollectionMode::Dependabot,
+                })
+                .collect(),
+        )
+    }
+}
+
+impl CollectionModeSet {
+    /// Does our collection mode respect `.gitignore` files?
     pub(crate) fn respects_gitignore(&self) -> bool {
-        matches!(
-            self,
-            CollectionMode::Default | CollectionMode::WorkflowsOnly | CollectionMode::ActionsOnly
-        )
+        // All modes except 'all' respect .gitignore files.
+        !self.0.contains(&CollectionMode::All)
     }
 
+    /// Should we collect workflows?
     pub(crate) fn workflows(&self) -> bool {
-        matches!(
-            self,
-            CollectionMode::All | CollectionMode::Default | CollectionMode::WorkflowsOnly
-        )
+        self.0.iter().any(|mode| {
+            matches!(
+                mode,
+                CollectionMode::All | CollectionMode::Default | CollectionMode::Workflows
+            )
+        })
     }
 
+    /// Should we collect *only* workflows?
+    pub(crate) fn workflows_only(&self) -> bool {
+        self.0.len() == 1 && self.0.contains(&CollectionMode::Workflows)
+    }
+
+    /// Should we collect actions?
     pub(crate) fn actions(&self) -> bool {
-        matches!(
-            self,
-            CollectionMode::All | CollectionMode::Default | CollectionMode::ActionsOnly
-        )
+        self.0.iter().any(|mode| {
+            matches!(
+                mode,
+                CollectionMode::All | CollectionMode::Default | CollectionMode::Actions
+            )
+        })
+    }
+
+    /// Should we collect Dependabot configuration files?
+    pub(crate) fn dependabot(&self) -> bool {
+        self.0.iter().any(|mode| {
+            matches!(
+                mode,
+                CollectionMode::All | CollectionMode::Default | CollectionMode::Dependabot
+            )
+        })
     }
 }
 
@@ -401,7 +507,7 @@ pub(crate) fn tips(err: impl AsRef<str>, tips: &[impl AsRef<str>]) -> String {
 
 /// State used when collecting input groups.
 pub(crate) struct CollectionOptions {
-    pub(crate) mode: CollectionMode,
+    pub(crate) mode_set: CollectionModeSet,
     pub(crate) strict: bool,
     pub(crate) no_config: bool,
     /// Global configuration, if any.
@@ -450,7 +556,7 @@ enum Error {
     Lsp(#[from] lsp::Error),
     /// An error from the GitHub API client.
     #[error(transparent)]
-    Client(#[from] github_api::ClientError),
+    Client(#[from] github::ClientError),
     /// An error while loading audit rules.
     #[error("failed to load audit rules")]
     AuditLoad(#[source] anyhow::Error),
@@ -561,6 +667,10 @@ fn run(app: &mut App) -> Result<ExitCode, Error> {
         reg.with(indicatif_layer).init();
     }
 
+    eprintln!("🌈 zizmor v{version}", version = env!("CARGO_PKG_VERSION"));
+
+    let collection_mode_set = CollectionModeSet::from(app.collect.as_slice());
+
     let min_severity = match app.min_severity {
         Some(CliSeverity::Unknown) => {
             tracing::warn!("`unknown` is a deprecated minimum severity that has no effect");
@@ -595,7 +705,7 @@ fn run(app: &mut App) -> Result<ExitCode, Error> {
         .transpose()?;
 
     let collection_options = CollectionOptions {
-        mode: app.collect,
+        mode_set: collection_mode_set,
         strict: app.strict_collection,
         no_config: app.no_config,
         global_config,
@@ -624,6 +734,14 @@ fn run(app: &mut App) -> Result<ExitCode, Error> {
 
         for (input_key, input) in registry.iter_inputs() {
             Span::current().pb_set_message(input.key().filename());
+
+            if input.as_document().has_anchors() {
+                warn_once!(
+                    "one or more inputs contains YAML anchors; you may encounter crashes or unpredictable behavior"
+                );
+                warn_once!("for more information, see: https://docs.zizmor.sh/usage/#yaml-anchors");
+            }
+
             let config = registry.get_config(input_key.group());
             for (ident, audit) in audit_registry.iter_audits() {
                 tracing::debug!("running {ident} on {input}", input = input.key());
@@ -661,12 +779,24 @@ fn run(app: &mut App) -> Result<ExitCode, Error> {
         }
     };
 
-    if let Some(fix_mode) = app.fix {
-        output::fix::apply_fixes(fix_mode, &results, &registry).map_err(Error::Fix)?;
-    }
+    let all_fixed = if let Some(fix_mode) = app.fix {
+        let fix_result =
+            output::fix::apply_fixes(fix_mode, &results, &registry).map_err(Error::Fix)?;
+
+        // If all findings have applicable fixes and all were successfully applied,
+        // we should exit with success.
+        results.all_findings_have_applicable_fixes(fix_mode)
+            && fix_result.failed_count == 0
+            && fix_result.applied_count > 0
+    } else {
+        false
+    };
 
     if app.no_exit_codes || matches!(app.format, OutputFormat::Sarif) {
         Ok(ExitCode::SUCCESS)
+    } else if all_fixed {
+        // All findings were auto-fixed, no manual intervention needed
+        Ok(ExitCode::SUCCESS)
     } else {
         Ok(results.exit_code())
     }
@@ -704,12 +834,10 @@ fn main() -> ExitCode {
                         ConfigErrorInner::AuditSyntax(_, ident) => {
                             group = group.elements([
                                 Level::HELP.message(format!(
-                                    "check the configuration for the '{ident}' rule",
-                                    ident = ident
+                                    "check the configuration for the '{ident}' rule"
                                 )),
                                 Level::HELP.message(format!(
-                                    "see: https://docs.zizmor.sh/audits/#{ident}-configuration",
-                                    ident = ident
+                                    "see: https://docs.zizmor.sh/audits/#{ident}-configuration"
                                 )),
                             ]);
                         }
