@@ -306,6 +306,15 @@ fn use_trusted_publishing() -> Result<()> {
             .run()?
     );
 
+    // No use-trusted-publishing findings expected here.
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "use-trusted-publishing/issue-1191-repro.yml"
+            ))
+            .run()?
+    );
+
     Ok(())
 }
 
@@ -858,6 +867,17 @@ fn ref_version_mismatch() -> Result<()> {
             .run()?
     );
 
+    // Tags that point to other tags are handled correctly.
+    insta::assert_snapshot!(
+        zizmor()
+            .offline(false)
+            .input(input_under_test(
+                "ref-version-mismatch/nested-annotated-tags.yml"
+            ))
+            .run()?,
+        @"No findings to report. Good job! (1 suppressed)"
+    );
+
     Ok(())
 }
 
@@ -939,3 +959,166 @@ fn unsound_condition() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn dependabot_execution() -> Result<()> {
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "dependabot-execution/basic/dependabot.yml"
+            ))
+            .run()?,
+        @r"
+    error[dependabot-execution]: external code execution in Dependabot updates
+      --> @@INPUT@@:10:5
+       |
+     4 |   - package-ecosystem: pip
+       |     ---------------------- this ecosystem
+    ...
+    10 |     insecure-external-code-execution: allow
+       |     ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ enabled here
+       |
+       = note: audit confidence → High
+       = note: this finding has an auto-fix
+
+    1 findings (1 fixable): 0 informational, 0 low, 0 medium, 1 high
+    "
+    );
+
+    Ok(())
+}
+
+#[test]
+fn dependabot_cooldown() -> Result<()> {
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "dependabot-cooldown/missing/dependabot.yml"
+            ))
+            .run()?,
+        @r"
+    warning[dependabot-cooldown]: insufficient cooldown in Dependabot updates
+     --> @@INPUT@@:4:5
+      |
+    4 |   - package-ecosystem: pip
+      |     ^^^^^^^^^^^^^^^^^^^^^^ missing cooldown configuration
+      |
+      = note: audit confidence → High
+      = note: this finding has an auto-fix
+
+    1 findings (1 fixable): 0 informational, 0 low, 1 medium, 0 high
+    "
+    );
+
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "dependabot-cooldown/no-default-days/dependabot.yml"
+            ))
+            .run()?,
+        @r"
+    warning[dependabot-cooldown]: insufficient cooldown in Dependabot updates
+     --> @@INPUT@@:6:5
+      |
+    6 |     cooldown: {}
+      |     ^^^^^^^^^^^^ no default-days configured
+      |
+      = note: audit confidence → High
+      = note: this finding has an auto-fix
+
+    1 findings (1 fixable): 0 informational, 0 low, 1 medium, 0 high
+    ");
+
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "dependabot-cooldown/default-days-too-short/dependabot.yml"
+            ))
+            .run()?,
+        @r"
+    help[dependabot-cooldown]: insufficient cooldown in Dependabot updates
+     --> @@INPUT@@:7:7
+      |
+    7 |       default-days: 2
+      |       ^^^^^^^^^^^^^^^ insufficient default-days configured
+      |
+      = note: audit confidence → Medium
+      = note: this finding has an auto-fix
+
+    1 findings (1 fixable): 0 informational, 1 low, 0 medium, 0 high
+    ");
+
+    Ok(())
+}
+
+#[test]
+fn concurrency_limits() -> Result<()> {
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "concurrency-limits/missing.yml"
+            ))
+            .args(["--persona=pedantic"])
+            .run()?,
+        @r"
+    help[concurrency-limits]: insufficient job-level concurrency limits
+      --> @@INPUT@@:1:1
+       |
+     1 | / name: Workflow without concurrency
+     2 | | on: push
+     3 | | permissions: {}
+    ...  |
+    10 | |     - name: 1-ok
+    11 | |       run: echo ok
+       | |___________________^ missing concurrency setting
+       |
+       = note: audit confidence → High
+
+    1 finding: 0 informational, 1 low, 0 medium, 0 high
+    "
+    );
+
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "concurrency-limits/cancel-false.yml"
+            ))
+            .args(["--persona=pedantic"])
+            .run()?,
+        @r"
+    help[concurrency-limits]: insufficient job-level concurrency limits
+     --> @@INPUT@@:5:1
+      |
+    5 | / concurrency:
+    6 | |   group: ${{ github.workflow }}-${{ github.event.pull_request_number || github.ref }}
+    7 | |   cancel-in-progress: false
+      | |___________________________^ cancel-in-progress set to false
+      |
+      = note: audit confidence → High
+
+    1 finding: 0 informational, 1 low, 0 medium, 0 high
+    "
+    );
+
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "concurrency-limits/no-cancel.yml"
+            ))
+            .args(["--persona=pedantic"])
+            .run()?,
+        @r"
+    help[concurrency-limits]: insufficient job-level concurrency limits
+     --> @@INPUT@@:5:1
+      |
+    5 | concurrency: group
+      | ^^^^^^^^^^^^^^^^^^ concurrency is missing cancel-in-progress
+      |
+      = note: audit confidence → High
+
+    1 finding: 0 informational, 1 low, 0 medium, 0 high
+    "
+    );
+
+    Ok(())
+}
